==> tinyvisor-0.4.tar.gz: tinyvisor/vmm/core/svm_panic.c <==
/*
 * Copyright (c) 2007, 2008 University of Tsukuba
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. Neither the name of the University of Tsukuba nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <core/initfunc.h>
#include <core/printf.h>
#include "asm.h"
#include "constants.h"
#include "current.h"
#include "seg.h"
#include "svm_exitcode.h"
#include "svm_panic.h"

static void
svm_panic_dump2 (void)
{
}

void
svm_panic_dump (void)
{
	current->vmctl.panic_dump = svm_panic_dump2;
	printf ("VMCB %p (phys %08llX)\n", current->u.svm.vi.vmcb,
		current->u.svm.vi.vmcb_phys);
	printf ("EXITCODE: ");
	printexitcode (current->u.svm.vi.vmcb->exitcode);
	printf ("EXITINFO1 %08llX  ", current->u.svm.vi.vmcb->exitinfo1);
	printf ("EXITINFO2 %08llX  ", current->u.svm.vi.vmcb->exitinfo2);
	printf ("EXITINTINFO %08llX\n", current->u.svm.vi.vmcb->exitintinfo);
}

==> tinyvisor-1.6.tar.gz: tinyvisor/vmm/core/svm_panic.c <==
/*
 * Copyright (c) 2007, 2008 University of Tsukuba
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. Neither the name of the University of Tsukuba nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include "asm.h"
#include "constants.h"
#include "current.h"
#include "initfunc.h"
#include "printf.h"
#include "seg.h"
#include "svm_exitcode.h"
#include "svm_panic.h"

static void
svm_panic_dump2 (void)
{
}

void
svm_panic_dump (void)
{
	current->vmctl.panic_dump = svm_panic_dump2;
	printf ("VMCB %p (phys %08llX)\n", current->u.svm.vi.vmcb,
		current->u.svm.vi.vmcb_phys);
	printf ("EXITCODE: ");
	printexitcode (current->u.svm.vi.vmcb->exitcode);
	printf ("EXITINFO1 %08llX  ", current->u.svm.vi.vmcb->exitinfo1);
	printf ("EXITINFO2 %08llX  ", current->u.svm.vi.vmcb->exitinfo2);
	printf ("EXITINTINFO %08llX\n", current->u.svm.vi.vmcb->exitintinfo);
}

static void
svm_panic (void)
{
	/* FIXME */
}

INITFUNC ("panic0", svm_panic);
